@@ -1,24 +1,28 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
-use crate::{GLContext, GLTexture, Texture};
 use glib::translate::*;
-use glib::Cast;
+
+#[cfg(feature = "v4_12")]
+#[cfg_attr(docsrs, doc(cfg(feature = "v4_12")))]
+use crate::builders::GLTextureBuilder;
+use crate::{GLContext, GLTexture};
 
 impl GLTexture {
     #[doc(alias = "gdk_gl_texture_new")]
+    #[allow(clippy::missing_safety_doc)]
     pub unsafe fn new(context: &GLContext, id: u32, width: i32, height: i32) -> Self {
-        let ptr = ffi::gdk_gl_texture_new(
+        from_glib_full(ffi::gdk_gl_texture_new(
             context.to_glib_none().0,
             id,
             width,
             height,
             None,
             std::ptr::null_mut(),
-        );
-        Texture::from_glib_full(ptr).unsafe_cast()
+        ))
     }
 
     #[doc(alias = "gdk_gl_texture_new")]
+    #[allow(clippy::missing_safety_doc)]
     pub unsafe fn with_release_func<F: FnOnce() + 'static>(
         context: &GLContext,
         id: u32,
@@ -31,14 +35,26 @@ impl GLTexture {
             released_func();
         }
         let released_func = Box::new(release_func);
-        let ptr = ffi::gdk_gl_texture_new(
+        from_glib_full(ffi::gdk_gl_texture_new(
             context.to_glib_none().0,
             id,
             width,
             height,
             Some(destroy_closure::<F>),
             Box::into_raw(released_func) as glib::ffi::gpointer,
-        );
-        Texture::from_glib_full(ptr).unsafe_cast()
+        ))
+    }
+
+    #[cfg(feature = "v4_12")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "v4_12")))]
+    // rustdoc-stripper-ignore-next
+    /// Creates a new builder-pattern struct instance to construct [`GLTexture`]
+    /// objects.
+    ///
+    /// This method returns an instance of
+    /// [`GLTextureBuilder`](crate::builders::GLTextureBuilder) which can be
+    /// used to create [`GLTexture`] objects.
+    pub fn builder() -> GLTextureBuilder {
+        GLTextureBuilder::new()
     }
 }
