@@ -1,26 +1,23 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
-use crate::{Event, Toplevel, ToplevelSize};
-use glib::signal::connect_raw;
-use glib::signal::SignalHandlerId;
-use glib::translate::*;
-use glib::IsA;
-use std::boxed::Box as Box_;
-use std::mem::transmute;
+use std::{boxed::Box as Box_, mem::transmute};
 
-pub trait ToplevelExtManual {
-    #[doc(alias = "gdk_toplevel_inhibit_system_shortcuts")]
-    fn inhibit_system_shortcuts<P: AsRef<Event>>(&self, event: Option<&P>);
+use glib::{
+    signal::{connect_raw, SignalHandlerId},
+    translate::*,
+};
 
-    #[doc(alias = "gdk_toplevel_show_window_menu")]
-    fn show_window_menu<P: AsRef<Event>>(&self, event: &P) -> bool;
-    fn connect_compute_size<F: Fn(&Toplevel, &mut ToplevelSize) + 'static>(
-        &self,
-        f: F,
-    ) -> SignalHandlerId;
+use crate::{prelude::*, Toplevel, ToplevelSize};
+
+mod sealed {
+    pub trait Sealed {}
+    impl<T: super::IsA<super::Toplevel>> Sealed for T {}
 }
 
-impl<O: IsA<Toplevel>> ToplevelExtManual for O {
+// rustdoc-stripper-ignore-next
+/// Trait containing manually implemented methods of
+/// [`Toplevel`](crate::Toplevel).
+pub trait ToplevelExtManual: sealed::Sealed + IsA<Toplevel> {
     fn connect_compute_size<F: Fn(&Toplevel, &mut ToplevelSize) + 'static>(
         &self,
         f: F,
@@ -47,22 +44,6 @@ impl<O: IsA<Toplevel>> ToplevelExtManual for O {
             )
         }
     }
-
-    fn inhibit_system_shortcuts<P: AsRef<Event>>(&self, event: Option<&P>) {
-        unsafe {
-            ffi::gdk_toplevel_inhibit_system_shortcuts(
-                self.as_ref().to_glib_none().0,
-                event.map(|e| e.as_ref()).to_glib_none().0,
-            );
-        }
-    }
-
-    fn show_window_menu<P: AsRef<Event>>(&self, event: &P) -> bool {
-        unsafe {
-            from_glib(ffi::gdk_toplevel_show_window_menu(
-                self.as_ref().to_glib_none().0,
-                event.as_ref().to_glib_none().0,
-            ))
-        }
-    }
 }
+
+impl<O: IsA<Toplevel>> ToplevelExtManual for O {}
